package ru.myitschool.work.data

import android.util.Log
import ru.myitschool.work.data.dto.PassDto
import ru.myitschool.work.data.local.CredentialsLocalDataSource
import ru.myitschool.work.data.network.PassNetworkDataSource
import ru.myitschool.work.domain.entities.PassEntity
import ru.myitschool.work.domain.passes.PassRepository

class PassRepositoryImpl(
    private val networkDataSource: PassNetworkDataSource,
    private val credentialsLocalDataSource: CredentialsLocalDataSource
) : PassRepository {

    override suspend fun getCurrentPasses(pageNum: Int, pageSize: Int): Result<List<PassEntity>> {
        return map(
            networkDataSource.getCurrentPasses(
                pageNum,
                pageSize,
                credentialsLocalDataSource.getToken()
            )
        )
    }

    override suspend fun getUsersPasses(
        pageNum: Int,
        pageSize: Int,
        login: String
    ): Result<List<PassEntity>> {
        return map(
            networkDataSource.getUsersPasses(
                login = login,
                pageNum = pageNum,
                pageSize = pageSize,
                token = credentialsLocalDataSource.getToken()
            )
        )
    }

    private fun map(listDto: Result<List<PassDto>>): Result<List<PassEntity>> {
        return listDto.map { successListDto ->
            successListDto.mapNotNull { dto ->
                PassEntity(
                    type = dto.terminal?.type ?: return@mapNotNull null,
                    name = dto.terminal.name ?: return@mapNotNull null,
                    time = dto.time ?: return@mapNotNull null
                )
            }
        }
    }

}