package ru.myitschool.work.data.network

import io.ktor.client.call.body
import io.ktor.client.request.get
import io.ktor.client.request.headers
import io.ktor.http.HttpHeaders
import io.ktor.http.HttpStatusCode
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext
import ru.myitschool.work.core.Constants.SERVER_ADDRESS
import ru.myitschool.work.data.dto.PassDto

object PassNetworkDataSource {
    private val client = KtorClient.client

    suspend fun getCurrentPasses(
        pageNum: Int,
        pageSize: Int,
        token: String
    ): Result<List<PassDto>> =
        withContext(Dispatchers.IO) {
            runCatching {
                val response =
                    client.get("$SERVER_ADDRESS/api/passes/paginated/?page=$pageNum&size=$pageSize") {
                        headers {
                            append(HttpHeaders.Authorization, token)
                        }
                    }
                if (response.status != HttpStatusCode.OK)
                    error("${response.status}")
                response.body()
            }

        }

    suspend fun getUsersPasses(
        login: String,
        pageNum: Int,
        pageSize: Int,
        token: String
    ): Result<List<PassDto>> = withContext(Dispatchers.IO) {
        runCatching {

            val response =
                client.get("$SERVER_ADDRESS/api/passes?login=$login&pageNum=$pageNum&pageSize=$pageSize") {
                    headers {
                        append(HttpHeaders.Authorization, token)
                    }
                }
            if (response.status != HttpStatusCode.OK)
                error("Status ${response.status}")
            response.body()
        }

    }
}
