package ru.myitschool.work.ui.admin.view

import android.os.Bundle
import android.view.View
import androidx.appcompat.app.AlertDialog
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.paging.LoadState
import com.squareup.picasso.Picasso
import ru.myitschool.work.R
import ru.myitschool.work.databinding.FragmentUserBinding
import ru.myitschool.work.ui.admin.search.AdminViewModel
import ru.myitschool.work.ui.profile.PassesListAdapter
import ru.myitschool.work.utils.collectWithLifecycle
import ru.myitschool.work.utils.visibleOrGone

class ViewUserAsAdminFragment : Fragment(R.layout.fragment_user) {

    private var _binding: FragmentUserBinding? = null
    private val binding: FragmentUserBinding get() = _binding!!

    private val viewModel by viewModels<AdminViewModel> { AdminViewModel.Factory }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        _binding = FragmentUserBinding.bind(view)

        binding.findUser.visibleOrGone(false)
        binding.logout.visibleOrGone(false)

        viewModel.state.collectWithLifecycle(this) { state ->
            binding.refresh.isRefreshing = state is AdminViewModel.State.Loading
            binding.content.visibleOrGone(state is AdminViewModel.State.Show)

            when (state) {
                is AdminViewModel.State.Loading -> Unit
                is AdminViewModel.State.Show -> {
                    val user = state.user
                    binding.block.visibleOrGone(!user.isCardBlocked)
                    binding.unblock.visibleOrGone(user.isCardBlocked)
                    binding.fullname.text = user.name
                    binding.position.text = user.position
                    binding.lastEntry.text = user.lastVisit
                    Picasso.get().load(user.photoUrl).into(binding.photo)
                }

                is AdminViewModel.State.Error -> binding.error.text = state.errorMessage
                is AdminViewModel.State.Waiting -> Unit
            }
        }

//        viewModel.listState.collectWithLifecycle(this) { listState ->
//            adapter.submitData(listState)
//        }

//        adapter.loadStateFlow.collectWithLifecycle(this) { data ->
//            val dataState = data.refresh
//            binding.refresh.isRefreshing = dataState is LoadState.Loading
//            binding.error.visibleOrGone(dataState is LoadState.Error)
//
//            if (dataState is LoadState.Error) {
//                binding.error.text = dataState.error.toString()
//            }
//        }

        binding.refresh.setOnRefreshListener {
            viewModel.onRefresh()
//            adapter.refresh()
        }


        binding.block.setOnClickListener {
            AlertDialog.Builder(requireContext())
                .setTitle("Блокировка доступа")
                .setMessage("Вы уверены, что хотите заблокировать доступ работнику: ${binding.fullname}?")
                .setIcon(android.R.drawable.ic_dialog_alert)
                .setPositiveButton(android.R.string.ok) { _, _ -> viewModel.onBlock() }
                .show()
        }

        binding.unblock.setOnClickListener {
            viewModel.unblock()
        }

    }

    override fun onDestroy() {
        _binding = null
        super.onDestroy()
    }
}