import android.content.Context
import androidx.test.core.app.ApplicationProvider
import kotlinx.coroutines.test.runTest
import org.junit.Assert.assertEquals
import org.junit.Assert.assertNull
import org.junit.Before
import org.junit.Test
import org.junit.runner.RunWith
import org.robolectric.RobolectricTestRunner
import ru.myitschool.work.core.Constants
import ru.myitschool.work.data.PassRepositoryImpl
import ru.myitschool.work.data.local.CredentialsLocalDataSource
import ru.myitschool.work.data.network.PassNetworkDataSource
import ru.myitschool.work.domain.entities.PassEntity

@RunWith(RobolectricTestRunner::class)
class PassesRepositoryImplTest {

    private lateinit var repository: PassRepositoryImpl
    private lateinit var context: Context

    @Before
    fun setUp() {
        context = ApplicationProvider.getApplicationContext()
        CredentialsLocalDataSource.buildSource(
            context.getSharedPreferences(
                Constants.TOKEN_KEY,
                Context.MODE_PRIVATE
            )
        )
        repository = PassRepositoryImpl(
            networkDataSource = PassNetworkDataSource,
            credentialsLocalDataSource = CredentialsLocalDataSource.getInstance()
        )
    }

    @Test
    fun `When user authorized as user gets only its passes`() = runTest {
        CredentialsLocalDataSource.getInstance().updateToken("", "")
        assertEquals(
            listOf(
                PassEntity("", "", ""),
                PassEntity("", "", ""),
                PassEntity("", "", "")
            ),
            repository.getCurrentPasses(1, 3).getOrNull()
        )
    }

    @Test
    fun `When user authorized as admin gets any user's passes`() = runTest {
        CredentialsLocalDataSource.getInstance().updateToken("pivanov", "admin")
        assertEquals(
            listOf(
                PassEntity("", "", ""),
                PassEntity("", "", ""),
                PassEntity("", "", "")
            ),
            repository.getUsersPasses(1, 3, "").getOrNull()
        )
    }

    @Test
    fun `When user tries to access admin method error` () = runTest {
        CredentialsLocalDataSource.getInstance().updateToken("", "")
        assertNull(repository.getUsersPasses(1, 3, ""))
    }
}