import android.content.Context
import androidx.test.core.app.ApplicationProvider
import kotlinx.coroutines.test.runTest
import org.junit.Assert.assertNotNull
import org.junit.Assert.assertNull
import org.junit.Before
import org.junit.Test
import org.junit.runner.RunWith
import org.robolectric.RobolectricTestRunner
import ru.myitschool.work.core.Constants
import ru.myitschool.work.data.network.QrNetworkDataSource
import ru.myitschool.work.data.QrRepositoryImpl
import ru.myitschool.work.data.local.CredentialsLocalDataSource
import ru.myitschool.work.domain.entities.QrEntity

@RunWith(RobolectricTestRunner::class)
class QrRepositoryImplTest {

    private lateinit var context: Context
    private lateinit var repository: QrRepositoryImpl

    @Before
    fun setUp() {
        context = ApplicationProvider.getApplicationContext()
        CredentialsLocalDataSource.buildSource(
            context.getSharedPreferences(
                Constants.SERVER_ADDRESS,
                Context.MODE_PRIVATE
            )
        )
        repository = QrRepositoryImpl(
            networkDataSource = QrNetworkDataSource,
            credentialsLocalDataSource = CredentialsLocalDataSource.getInstance()
        )
    }

    @Test
    fun `When QR valid and user logged process`() = runTest {
        CredentialsLocalDataSource.getInstance().updateToken("", "")
        assertNull(repository.pushQr(QrEntity("")).exceptionOrNull())
    }

    @Test
    fun `When QR invalid and user logged error`() = runTest {
        CredentialsLocalDataSource.getInstance().updateToken("", "")
        assertNotNull(repository.pushQr(QrEntity("*")).exceptionOrNull())
    }

    @Test
    fun `When QR valid and user not logged error`() = runTest {
        runCatching {
            repository.pushQr(QrEntity("*")).exceptionOrNull()
        }.let { assert(it.isFailure) }
    }
}